@@ -69,6 +69,9 @@ GtkTreeModel *sortmons;
 /* Number of desktops */
 int ndesks;
 
+/* Is new theme available? */
+gboolean trix_theme = FALSE;
+
 #ifndef PLUGIN_NAME
 static gulong draw_id;
 
@@ -83,6 +86,7 @@ static int orig_darkmode;
 /* Prototypes                                                                 */
 /*----------------------------------------------------------------------------*/
 
+static void update_greeter (void);
 static int n_desktops (void);
 static gboolean ok_clicked (GtkButton *button, gpointer data);
 static void init_config (void);
@@ -166,14 +170,6 @@ char *rgba_to_gdk_color_string (GdkRGBA *col)
     return g_strdup_printf ("#%02X%02X%02X", r, g, b);
 }
 
-const char *session (void)
-{
-    const char *session_name =  g_getenv ("DESKTOP_SESSION");
-    if (!session_name) return "LXDE-pi";
-    if (!strncmp (session_name, "LXDE-pi", 7)) return "LXDE-pi";
-    else return session_name;
-}
-
 static int n_desktops (void)
 {
     int n, m;
@@ -198,6 +194,23 @@ void check_directory (const char *path)
     g_free (dir);
 }
 
+const char *theme_name (int dark)
+{
+    if (trix_theme)
+        return dark == TEMP ? "tPiXonyx" : (dark ? "PiXonyx" : "PiXtrix");
+    else
+        return dark == TEMP ? "tPiXflat" : (dark ? "PiXnoir" : "PiXflat");
+}
+
+static void update_greeter (void)
+{
+    if (g_file_test (GREETER_TMP, G_FILE_TEST_IS_REGULAR))
+    {
+        system (SUDO_PREFIX "cp " GREETER_TMP " /etc/lightdm/pi-greeter.conf");
+        remove (GREETER_TMP);
+    }
+}
+
 /*----------------------------------------------------------------------------*/
 /* Message box                                                                */
 /*----------------------------------------------------------------------------*/
@@ -246,6 +259,10 @@ static void init_config (void)
 {
     int i;
     char *buf;
+    struct stat st;
+
+    // check to see if new theme is installed
+    if (stat ("/usr/share/themes/PiXtrix", &st) == 0) trix_theme = TRUE;
 
     // find the number of monitors
     ndesks = n_desktops ();
@@ -276,7 +293,7 @@ static void init_config (void)
     load_defaults_tab (builder);
 
     // create session file to be tracked
-    init_session (cur_conf.darkmode ? DEFAULT_THEME_DARK : DEFAULT_THEME);
+    init_session (theme_name (cur_conf.darkmode));
 
     // set up controls to match current state of data
     set_desktop_controls ();
@@ -327,6 +344,18 @@ const char *tab_name (int tab)
     }
 }
 
+const char *icon_name (int tab)
+{
+    switch (tab)
+    {
+        case 0 : return "appset-desktop";
+        case 1 : return "appset-taskbar";
+        case 2 : return "preferences-desktop-theme";
+        case 3 : return "applications-utilities";
+        default : return NULL;
+    }
+}
+
 const char *tab_id (int tab)
 {
     switch (tab)
@@ -367,6 +396,7 @@ GtkWidget *get_tab (int tab)
 
 gboolean reboot_needed (void)
 {
+    update_greeter ();
     return system_reboot ();
 }
 
@@ -398,8 +428,7 @@ static void backup_file (char *filepath)
 
 static void backup_config_files (void)
 {
-    const char *session_name = session ();
-    char *path, *lc_sess, *fname, *monname;
+    char *path, *monname;
     int i;
 
     // delete any old backups and create a new backup directory
@@ -408,29 +437,16 @@ static void backup_config_files (void)
     g_mkdir_with_parents (path, S_IRUSR | S_IWUSR | S_IXUSR);
     g_free (path);
 
-    lc_sess = g_ascii_strdown (session_name, -1);
-    fname = g_strconcat (lc_sess, "-rc.xml", NULL);
-    path = g_build_filename (".config/openbox", fname, NULL);
-    backup_file (path);
-    g_free (path);
-    g_free (fname);
-    g_free (lc_sess);
-
-    path = g_build_filename (".config/lxsession", session_name, "desktop.conf", NULL);
-    backup_file (path);
-    g_free (path);
-
-    path = g_build_filename (".config/lxpanel", session_name, "panels/panel", NULL);
-    backup_file (path);
-    g_free (path);
+    backup_file (".config/openbox/rpd-rc.xml");
+    backup_file (".config/lxsession/rpd-x/desktop.conf");
+    backup_file (".config/lxpanel-pi/panels/panel");
+    backup_file (".config/pcmanfm/default/pcmanfm.conf");
 
     for (i = 0; i < ndesks; i++)
     {
-        fname = g_strdup_printf ("desktop-items-%d.conf", i);
-        path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+        path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%d.conf", i);
         backup_file (path);
         g_free (path);
-        g_free (fname);
 
         if (wm != WM_OPENBOX)
         {
@@ -438,28 +454,22 @@ static void backup_config_files (void)
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
             monname = gdk_screen_get_monitor_plug_name (gdk_display_get_default_screen (gdk_display_get_default ()), i);
 #pragma GCC diagnostic pop
-            fname = g_strdup_printf ("desktop-items-%s.conf", monname);
-            path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+            path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%s.conf", monname);
             backup_file (path);
             g_free (path);
-            g_free (fname);
             g_free (monname);
         }
     }
 
-    path = g_build_filename (".config/pcmanfm", session_name, "pcmanfm.conf", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (LIGHT), "gtk-3.0/gtk.css", NULL);
     backup_file (path);
     g_free (path);
 
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME, "gtk-3.0/gtk.css", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (DARK), "gtk-3.0/gtk.css", NULL);
     backup_file (path);
     g_free (path);
 
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME_DARK, "gtk-3.0/gtk.css", NULL);
-    backup_file (path);
-    g_free (path);
-
-    backup_file (".config/wf-panel-pi.ini");
+    backup_file (".config/wf-panel-pi/wf-panel-pi.ini");
     backup_file (".config/libfm/libfm.conf");
     backup_file (".config/gtk-3.0/gtk.css");
     backup_file (".config/qt5ct/qt5ct.conf");
@@ -502,33 +512,19 @@ static int restore_file (char *filepath)
 
 static int restore_config_files (void)
 {
-    const char *session_name = session ();
-    char *path, *lc_sess, *fname, *monname;
+    char *path, *monname;
     int i, changed = 0;
 
-    lc_sess = g_ascii_strdown (session_name, -1);
-    fname = g_strconcat (lc_sess, "-rc.xml", NULL);
-    path = g_build_filename (".config/openbox", fname, NULL);
-    restore_file (path);
-    g_free (path);
-    g_free (fname);
-    g_free (lc_sess);
-
-    path = g_build_filename (".config/lxsession", session_name, "desktop.conf", NULL);
-    if (restore_file (path)) changed = 1;
-    g_free (path);
-
-    path = g_build_filename (".config/lxpanel", session_name, "panels/panel", NULL);
-    if (restore_file (path)) changed = 1;
-    g_free (path);
+    restore_file (".config/openbox/rpd-rc.xml");
+    if (restore_file (".config/lxsession/rpd-x/desktop.conf")) changed = 1;
+    if (restore_file (".config/lxpanel-pi/panels/panel")) changed = 1;
+    if (restore_file (".config/pcmanfm/default/pcmanfm.conf")) changed = 1;
 
     for (i = 0; i < ndesks; i++)
     {
-        fname = g_strdup_printf ("desktop-items-%d.conf", i);
-        path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+        path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%d.conf", i);
         if (restore_file (path)) changed = 1;
         g_free (path);
-        g_free (fname);
 
         if (wm != WM_OPENBOX)
         {
@@ -536,28 +532,22 @@ static int restore_config_files (void)
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
             monname = gdk_screen_get_monitor_plug_name (gdk_display_get_default_screen (gdk_display_get_default ()), i);
 #pragma GCC diagnostic pop
-            fname = g_strdup_printf ("desktop-items-%s.conf", monname);
-            path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+            path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%s.conf", monname);
             if (restore_file (path)) changed = 1;
             g_free (path);
-            g_free (fname);
             g_free (monname);
         }
     }
 
-    path = g_build_filename (".config/pcmanfm", session_name, "pcmanfm.conf", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (LIGHT), "gtk-3.0/gtk.css", NULL);
     if (restore_file (path)) changed = 1;
     g_free (path);
 
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME, "gtk-3.0/gtk.css", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (DARK), "gtk-3.0/gtk.css", NULL);
     if (restore_file (path)) changed = 1;
     g_free (path);
 
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME_DARK, "gtk-3.0/gtk.css", NULL);
-    if (restore_file (path)) changed = 1;
-    g_free (path);
-
-    if (restore_file (".config/wf-panel-pi.ini")) changed = 1;
+    if (restore_file (".config/wf-panel-pi/wf-panel-pi.ini")) changed = 1;
     if (restore_file (".config/libfm/libfm.conf")) changed = 1;
     if (restore_file (".config/gtk-3.0/gtk.css")) changed = 1;
     if (restore_file (".config/qt5ct/qt5ct.conf")) changed = 1;
@@ -583,7 +573,7 @@ static gpointer restore_thread (gpointer ptr)
     if (restore_config_files ())
     {
         cur_conf.darkmode = orig_darkmode;
-        set_theme (TEMP_THEME);
+        set_theme (theme_name (TEMP));
         reload_session ();
         reload_panel ();
         reload_desktop ();
@@ -599,6 +589,7 @@ static gpointer restore_thread (gpointer ptr)
 
 static gboolean ok_main (GtkButton *button, gpointer data)
 {
+    update_greeter ();
     gtk_main_quit ();
     return FALSE;
 }
@@ -626,6 +617,7 @@ static gboolean cancel_main (GtkButton *button, gpointer data)
 
 static gboolean close_prog (GtkWidget *widget, GdkEvent *event, gpointer data)
 {
+    update_greeter ();
     gtk_main_quit ();
     return TRUE;
 }
